package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````@"D```````!``````````!"D````
M`````````$``.``-`$``(``?``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````+@4````````N!0`````````
M$`````````$````%`````"``````````(``````````@````````W24`````
M``#=)0`````````0`````````0````0`````4`````````!0`````````%``
M```````81````````!A$`````````!`````````!````!@```)";````````
MD*L```````"0JP```````($$````````X`0`````````$`````````(````&
M````R)L```````#(JP```````,BK````````,`(````````P`@````````@`
M````````!`````0````X`P```````#@#````````.`,```````!0````````
M`%``````````"``````````$````!````(@#````````B`,```````"(`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````4`````````!0``````````@`````````4.5T9`0`
M``!TD````````'20````````=)````````"<`````````)P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````D)L```````"0JP```````)"K````
M````<`0```````!P!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````0`````4```!'3E4``@``P`0````#````````
M``*``,`$````!P`````````!``'`!````!D``````````@`!P`0````%````
M``````0````4`````P```$=.50##%#W`&`N()HVM0VG*G4F-D-1&T00````0
M`````0```$=.50```````P````(```````````````,````^`````0````8`
M```0"0``P`%``CX```!``````````*;=HVL+BA!7Q+F<0#GRBQP`````````
M````````````````````````````H@(``!(`````````````````````````
M"0(``!(`````````````````````````B0(``!(`````````````````````
M````=0$``!(`````````````````````````W0$``!(`````````````````
M````````10(``!(``````````````````````````0```"``````````````
M````````````R````!(`````````````````````````9P```!(`````````
M````````````````Y````!(`````````````````````````@P```!(`````
M````````````````````@@(``!(`````````````````````````U`(``!(`
M````````````````````````^0$``!(`````````````````````````"0$`
M`!(`````````````````````````&0$``!(`````````````````````````
M9P$``!(`````````````````````````ZP$``!(`````````````````````
M````O0$``!(`````````````````````````$````"``````````````````
M````````N@(``!(`````````````````````````IP(``!(`````````````
M````````````BP```!(`````````````````````````+````"``````````
M````````````````S@```!(`````````````````````````Z0```!(`````
M````````````````````N0```!(`````````````````````````K`(``!(`
M````````````````````````6````"(`````````````````````````'P$`
M`!8`````````````````````````,@$``!(`````````````````````````
M6`(``!(`````````````````````````30$``!(`````````````````````
M````Q0(``!(`````````````````````````D@```!(`````````````````
M````````\@$``!(`````````````````````````?`$``!(`````````````
M````````````7@$``!(`````````````````````````H0$``!(`````````
M````````````````E`(``!(`````````````````````````S`$``!(`````
M````````````````````F@```!(`````````````````````````*@(``!(`
M````````````````````````H0```!(`````````````````````````KP$`
M`!(`````````````````````````J`$``!(`````````````````````````
MS0```!(`````````````````````````M@$``!(`````````````````````
M````%0(``!(`````````````````````````=@(``!(`````````````````
M````````W````!(`````````````````````````$`$``!(`````````````
M````````````^P```!(`````````````````````````U0```!(`````````
M````````````````F0$``!(`````````````````````````0@$``!(`````
M````````````````````BP$``!(`````````````````````````-@(``!(`
M````````````````````````1@```!(`````````````````````````\0``
M`!(`````````````````````````Q@$``!(`````````````````````````
M>P```"$`&P`@L`````````@`````````:0(``!$`&P!(L`````````$`````
M````>0```!$`&P`@L`````````@`````````L@```!$`&P!`L`````````@`
M`````````%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%]?;&EB8U]S=&%R=%]M
M86EN`%]?8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?871F;W)K`%]?96YV:7)O
M;@!S=')N8VUP`'-T<FQE;@!S=')R8VAR`'-T<F1U<`!?7W-T86-K7V-H:U]F
M86EL`'-T9&5R<@!?7W9F<')I;G1F7V-H:P!E>&ET`&QS=&%T-C0`86-C97-S
M`&QS965K-C0`<F5A9`!O<&5N9&ER`')E861D:7(V-`!?7W-P<FEN=&9?8VAK
M`'5N;&EN:P!C;&]S961I<@!R;61I<@!03%]C=7)R96YT7V-O;G1E>'0`8F]O
M=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D
M;&EN:P!097)L7W-V7W-E='!V`&UE;6-H<@!097)L7W-V7W-E='!V;@!?7VUE
M;6UO=F5?8VAK`')E86QL;V,`<W1R8VAR`'-T<G1O:P!S=')C;7``9V5T=6ED
M`&=E='!W=6ED`&UK9&ER`%]?97)R;F]?;&]C871I;VX`7U]F<')I;G1F7V-H
M:P!G971P:60`;W!E;C8T`%!E<FQ?9W9?9F5T8VAP=@!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!097)L7W-Y<U]I;FET
M,P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U
M;F1U;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R<V4`<&5R;%]D97-T
M<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V%L;&]C`'!E<FQ?
M8V]N<W1R=6-T`'!E<FQ?<G5N`&QI8G!E<FPN<V\N-2XT,`!L:6)C+G-O+C8`
M1TQ)0D-?04))7T147U)%3%(`1TQ)0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?
M,BXS,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C,N-`!'3$E"0U\R+C(N-0`````!
M``$``0`"``,``0`!``(`!``"``(``@`!``$``@`"``$``@`"``$``0`"``(`
M`0`%``(``P`!``(``0`!``$``0`!``(``@`!``(``@`!``(``@`!``8``@`"
M``4``@`!``$``@`"``,``@`"``$``P`!``<``@`"``(``0`"``(`````````
M`0`'`.T"```0`````````$(._0````@`]P(``!````"TD98&```'``D#```0
M````%&EI#0``!@`4`P``$````+.1E@8```4`'@,``!````!R&6D)```$`"D#
M```0````=!EI"0```P`U`P``$````'4::0D```(`00,```````"XKP``````
M``8````&``````````````#`KP````````8````'``````````````#(KP``
M``````8````4``````````````#0KP````````8````8``````````````#8
MKP````````8````=``````````````#@KP```````!(````>````````````
M``#HKP````````8````?``````````````#PKP````````8````@````````
M``````#XKP````````8````[```````````````@L`````````4```!`````
M``````````!`L`````````4```!!``````````````!(L`````````4````_
M```````````````0K@````````<````!```````````````8K@````````<`
M```"```````````````@K@````````<````#```````````````HK@``````
M``<````$```````````````PK@````````<````%```````````````XK@``
M``````<````(``````````````!`K@````````<````)``````````````!(
MK@````````<````*``````````````!0K@````````<````+````````````
M``!8K@````````<````,``````````````!@K@````````<````-````````
M``````!HK@````````<````.``````````````!PK@````````<````/````
M``````````!XK@````````<````0``````````````"`K@````````<````1
M``````````````"(K@````````<````2``````````````"0K@````````<`
M```3``````````````"8K@````````<````5``````````````"@K@``````
M``<````6``````````````"HK@````````<````7``````````````"PK@``
M``````<````9``````````````"XK@````````<````:``````````````#`
MK@````````<````;``````````````#(K@````````<````<````````````
M``#0K@````````<````=``````````````#8K@````````<````A````````
M``````#@K@````````<````B``````````````#HK@````````<````C````
M``````````#PK@````````<````D``````````````#XK@````````<````E
M````````````````KP````````<````F```````````````(KP````````<`
M```G```````````````0KP````````<````H```````````````8KP``````
M``<````I```````````````@KP````````<````J```````````````HKP``
M``````<````K```````````````PKP````````<````L```````````````X
MKP````````<````M``````````````!`KP````````<````N````````````
M``!(KP````````<````O``````````````!0KP````````<````P````````
M``````!8KP````````<````Q``````````````!@KP````````<````R````
M``````````!HKP````````<````S``````````````!PKP````````<````T
M``````````````!XKP````````<````U``````````````"`KP````````<`
M```V``````````````"(KP````````<````W``````````````"0KP``````
M``<````X``````````````"8KP````````<````Y``````````````"@KP``
M``````<````Z``````````````"HKP````````<````\``````````````"P
MKP````````<````]``````````````"0JP```````'\`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!;&/``!(A<!T`O_02(/$",,``````/\UVHT``/\EW(T`
M``\?0`#S#Q[Z:`````#IXO___V:0\P\>^F@!````Z=+___]FD/,/'OIH`@``
M`.G"____9I#S#Q[Z:`,```#ILO___V:0\P\>^F@$````Z:+___]FD/,/'OIH
M!0```.F2____9I#S#Q[Z:`8```#I@O___V:0\P\>^F@'````Z7+___]FD/,/
M'OIH"````.EB____9I#S#Q[Z:`D```#I4O___V:0\P\>^F@*````Z4+___]F
MD/,/'OIH"P```.DR____9I#S#Q[Z:`P```#I(O___V:0\P\>^F@-````Z1+_
M__]FD/,/'OIH#@```.D"____9I#S#Q[Z:`\```#I\O[__V:0\P\>^F@0````
MZ>+^__]FD/,/'OIH$0```.G2_O__9I#S#Q[Z:!(```#IPO[__V:0\P\>^F@3
M````Z;+^__]FD/,/'OIH%````.FB_O__9I#S#Q[Z:!4```#IDO[__V:0\P\>
M^F@6````Z8+^__]FD/,/'OIH%P```.ER_O__9I#S#Q[Z:!@```#I8O[__V:0
M\P\>^F@9````Z5+^__]FD/,/'OIH&@```.E"_O__9I#S#Q[Z:!L```#I,O[_
M_V:0\P\>^F@<````Z2+^__]FD/,/'OIH'0```.D2_O__9I#S#Q[Z:!X```#I
M`O[__V:0\P\>^F@?````Z?+]__]FD/,/'OIH(````.GB_?__9I#S#Q[Z:"$`
M``#ITOW__V:0\P\>^F@B````Z<+]__]FD/,/'OIH(P```.FR_?__9I#S#Q[Z
M:"0```#IHOW__V:0\P\>^F@E````Z9+]__]FD/,/'OIH)@```.F"_?__9I#S
M#Q[Z:"<```#I<OW__V:0\P\>^F@H````Z6+]__]FD/,/'OIH*0```.E2_?__
M9I#S#Q[Z:"H```#I0OW__V:0\P\>^F@K````Z3+]__]FD/,/'OIH+````.DB
M_?__9I#S#Q[Z:"T```#I$OW__V:0\P\>^F@N````Z0+]__]FD/,/'OIH+P``
M`.GR_/__9I#S#Q[Z:#````#IXOS__V:0\P\>^F@Q````Z=+\__]FD/,/'OIH
M,@```.G"_/__9I#S#Q[Z:#,```#ILOS__V:0\P\>^F@T````Z:+\__]FD/,/
M'OK_)8:*``!F#Q]$``#S#Q[Z_R5^B@``9@\?1```\P\>^O\E=HH``&8/'T0`
M`/,/'OK_)6Z*``!F#Q]$``#S#Q[Z_R5FB@``9@\?1```\P\>^O\E7HH``&8/
M'T0``/,/'OK_)5:*``!F#Q]$``#S#Q[Z_R5.B@``9@\?1```\P\>^O\E1HH`
M`&8/'T0``/,/'OK_)3Z*``!F#Q]$``#S#Q[Z_R4VB@``9@\?1```\P\>^O\E
M+HH``&8/'T0``/,/'OK_)2:*``!F#Q]$``#S#Q[Z_R4>B@``9@\?1```\P\>
M^O\E%HH``&8/'T0``/,/'OK_)0Z*``!F#Q]$``#S#Q[Z_R4&B@``9@\?1```
M\P\>^O\E_HD``&8/'T0``/,/'OK_)?:)``!F#Q]$``#S#Q[Z_R7NB0``9@\?
M1```\P\>^O\EYHD``&8/'T0``/,/'OK_)=Z)``!F#Q]$``#S#Q[Z_R76B0``
M9@\?1```\P\>^O\ESHD``&8/'T0``/,/'OK_)<:)``!F#Q]$``#S#Q[Z_R6^
MB0``9@\?1```\P\>^O\EMHD``&8/'T0``/,/'OK_):Z)``!F#Q]$``#S#Q[Z
M_R6FB0``9@\?1```\P\>^O\EGHD``&8/'T0``/,/'OK_)9:)``!F#Q]$``#S
M#Q[Z_R6.B0``9@\?1```\P\>^O\EAHD``&8/'T0``/,/'OK_)7Z)``!F#Q]$
M``#S#Q[Z_R5VB0``9@\?1```\P\>^O\E;HD``&8/'T0``/,/'OK_)6:)``!F
M#Q]$``#S#Q[Z_R5>B0``9@\?1```\P\>^O\E5HD``&8/'T0``/,/'OK_)4Z)
M``!F#Q]$``#S#Q[Z_R5&B0``9@\?1```\P\>^O\E/HD``&8/'T0``/,/'OK_
M)3:)``!F#Q]$``#S#Q[Z_R4NB0``9@\?1```\P\>^O\E)HD``&8/'T0``/,/
M'OK_)1Z)``!F#Q]$``#S#Q[Z_R46B0``9@\?1```\P\>^O\E#HD``&8/'T0`
M`/,/'OK_)0:)``!F#Q]$``#S#Q[Z_R7^B```9@\?1```\P\>^O\E]H@``&8/
M'T0``/,/'OK_)>Z(``!F#Q]$``#S#Q[Z_R7FB```9@\?1```````````````
M`````````/,/'OI52(GE055!5%-(@^PXB7W,2(U]S$B)=<!(C77`2(E5N&1(
MBQ0E*````$B)5=A(C56XZ(;___](BS67B```2(L]R(@``$B)\NB0'@``@#T1
MB0````^$'0$``$B+!9R(``!D2(L`@(@Z!````XM%S(UX!(U8`TAC_TC!YP/H
MO/[__TB+?<!$BT7,2(G!2(D%\H@``$B+!TB)`4B-!5@J``!(B4$(2(T%8BL`
M`$B)01!(C05%*@``2(E!&$&#^`$/CKD!``!(@\<(08/``[H$````9F8N#Q^$
M``````"02(L'2&/R@\(!2(/'"$B)!/%$.<)UZDACTDB+/7B(``!%,<!(C36V
M"```2,<$T0````")VNBG^___A<`/A(T```!(BSU0B```3(UEU.AO_?__3(GF
M2(T]."D``(G#,<#H7`(``$B%P'1V2(L]*(@``.A+^___Z+;\__](BT789$@K
M!"4H````#X4=`0``2(/$.(G86T%<05U=P^@Q_/__2(D%\H<``$B)QTB%P`^$
M_0```.BI_/__2(L%8H<``&1(BQ#&@K8(````Z;;^__](BSW#AP``Z(;[___I
M8O___TR++;J'``!-A>T/A(H````QP$R)YDB-/2(H``#HP`$``$B%P`^$8/__
M_P^V`(3`#X15____/#`/A$W___]!@'T```^$0O___TR)[^AA`@``OB\```!(
MB<=)B<3H,?S__TB%P'0$3(U@`4R)Y^B0_/__N@0```!(C36R)P``2(G'Z-SZ
M__^%P`^%_?[__TR)[^CL!0``Z?#^__],B>9(C3TB)P``Z#@!``!(B041AP``
M28G%2(7`#X3._O__Z4____^Z!````.EL_O__Z%'\__^_`0```.A7^O__#Q^`
M`````/,/'OHQ[4F)T5Y(B>)(@^3P4%1%,<`QR4B-/4']____%5.&``#T9BX/
M'X0``````$B-/6&&``!(C05:A@``2#GX=!5(BP7^A0``2(7`=`G_X`\?@```
M``###Q^``````$B-/3&&``!(C34JA@``2"G^2(GP2,'N/TC!^`-(`<9(T?YT
M%$B+!<6%``!(A<!T"/_@9@\?1```PP\?@`````#S#Q[Z@#T>A@```'4K54B#
M/:*%````2(GE=`Q(C3U>@0``Z+GZ___H9/___\8%]H4```%=PP\?`,,/'X``
M````\P\>^NEW____9BX/'X0``````&8N#Q^$```````/'P!52(GE05=!5D%5
M05132(/L&$R+-8B%``!(B77(387V#X2B````#[8'28G]A,!T!#P]=5U%,>1)
MBQY(A=MT.$UCY$V)]V9F+@\?A```````D$R)XDR)[DB)W^@B^?__A<!U!T*`
M/",]=$=)BU\(28/'"$B%VW7:2(/$&$B)V%M!7$%=05Y!7UW##Q^$``````!)
MB?Q!#[9$)`%)@\0!A,!T!#P]=>Y%*>SKC&8/'T0``$R)^4B+1<A*C5PC`4PI
M\4C!^0.)".NO,=OKJP\?1```54B)Y4%44TB![``0``!(@PPD`$B#[!!D2(L$
M)2@```!(B47H,<"`/P`/A,P```!)B?SH*?G__TB)PDB-0`%(/0`0```/A]P`
M``!(C9W@[___2(G?@_@(<@Z)P4R)YL'I`_-(I4F)]#')J`1T"T&+#"2)#[D$
M````J`)T#D4/MP0,9D2)!`](@\$"J`%T"$$/M@0,B`0/2(U$$_](.<-R'.L?
M9F8N#Q^$```````/'P#&``!(@^@!2#G8=`6`."]T[[XO````2(G?Z!+Y__](
MA<!T*$@YPW))2(G?Z'#Y__](BU7H9$@K%"4H````=3M(@<00$```6T%<7<-(
MBT7H9$@K!"4H````=2!(@<00$```2(T]G",``%M!7%WI+_G__\8``.NR,<#K
MMNA!^?__D%5(B>5(@>S0````2(FU6/___TB)E6#___](B8UH____3(F%</__
M_TR)C7C___^$P'0HQ?@I18#%^"E-D,7X*56@Q?@I7;#%^"EEP,7X*6W0Q?@I
M=>#%^"E]\&1(BP0E*````$B)A4C___\QP$B)^DB-11!(BSU&@P``2(F%./__
M_[X"````2(V%4/___TB-C3#____'A3#___\(````QX4T____,````$B)A4#_
M___HK/?__[__````Z)+V__]FD%5(B>532(VU4/___TB![*@```!D2(L<)2@`
M``!(B5WH2(G[Z(CX__^%P'4TBY5H____@>(`\```@?H`0```=`B!^@"@``!U
M&KX"````2(G?Z,OX__^%P`^4P`^VP.L#D#'`2(M5Z&1(*Q0E*````'4&2(M=
M^,G#Z`3X__\/'T``54B)Y4%505133(V<)```__](@>P`$```2(,,)`!,.=QU
M[TB#[!BZ`@```#'V9$R++"4H````3(EMV$&)_4B-G=#__O_H)_C__TR-8/],
MB>)(P?H_2,'J,$F-!!0/M\!(*=!)*<0/B*$````/'T0``#'23(GF1(GOZ//W
M__](@_C_#X2K````N@@``0!(B=Y$B>_HF?7__X/X_W1Y2)A(@_@'=E1(C40#
M^$@YV')*2(T5DX$``.L29@\?A```````2(/H`4@YV'(O2(L(2#D*=>](*=A,
M`>!(BU789$@K%"4H````=6E(@<08``$`6T%<05U=PP\?0`!)@>P```$`28'\
M``#__P^%9/___TC'P/_____KPDB+1=AD2"L$)2@```!U*TB-/2@A```QP.B.
M_?__2(M%V&1(*P0E*````'4.2(T]_B```#'`Z'']___HK/;__V9F+@\?A```
M````D%5(B>5!5T%6055!5%-(@>RH````9$B+!"4H````2(E%R#'`2(7_=`B`
M/P!(B?MU*$B+1<AD2"L$)2@````/A2P!``!(@<2H````6T%<05U!7D%?7<,/
M'P#H4_7__TF)Q4B%P'3+3(GOZ"/W__](A<`/A+H```"`>!,N3(U@$W4008!\
M)`$`=-T/'X0``````(!X$RX/A*X```!(B=_H[O3__TR)YTF)QNCC]/__18U\
M!@)-8_],B?_H,_3__TV)X4F)V$R)^DF)QDB)Q[X"````,<!(C0TE(```Z%'V
M__],B?=(C;4P____Z++T__],B?>#^/]T$HN%2/___R4`\```/0!```!T8.@3
M]/__3(GWZ&OT__],B>_H<_;__TB%P`^%4/___V8N#Q^$``````!,B>_HZ/7_
M_TB)W^CP\___Z>O^__\/'P!!@'PD`2X/A4;___]!@'PD`@`/A`7____I-?__
M_P\?`.B3_O__ZY[H+/7__V9F+@\?A```````D/,/'OI52(T-O%\``$B--7(?
M``!(B>532(/L"$B+'1Y_``!(BQ4??P``9$B+.^BN]?__9$B+.TB+7?A,C077
M(```R44QR4B-%70.``!,B<%(C35+'P``Z17T__\/'T0``%5(B>5!5D%50513
M2('L`!```$B##"0`2(/L$+K_#P``9$R+)"4H````3(EEV$F)]$R-K=#O__](
MB?M(C3T5'P``3(GNZ!?T__^%P'X6B<&#Z`%(8]"`O!70[___`'5!A<!U-4B+
M!79^``!,B>)(B=YD2(LXZ.?R__](BT789$@K!"4H````=4M(@<00$```6T%<
M05U!7EW#B<%F#Q]$``!,8_&^+P```$R)[TR)\NC]\?__2(7`=*M(BP4A?@``
M3(GQ3(GJ2(G>9$B+..A_\___ZZ;HZ//__P\?A```````53'`2(GE05=!5D%5
M05132(G[2(/L*(`^/61,BRPE*````$R);<A)B?4/E,!)`<5,B>_HF?+__TB-
M=<1(B=])B<0QP.A8^/__2(7`#X0G`0``2(G'28G&Z'3R__],.>`/@_,```!,
M8T7$3HT\Q0`````/M@.$P`^$Y`$``#P]#X3<`0``2(G89F8N#Q^$``````!F
M9BX/'X0```````\?``^V4`%(@\`!A-)T!8#Z/77O2"G82)A,BS6#?0``2HU\
M(`+H:?'__TT!_DF)!DB%P'1@2(L%9WT``$B-2P%*BQ0X#[8#B`(\/70KA,!U
M%NLE9F8N#Q^$```````/'T0``#P]=!$/M@%(@\(!2(/!`8@"A,!UZ\8"/3'`
M9@\?1```00^V3`4`B$P"`4B#P`&$R77N2(M%R&1(*P0E*`````^%+P$``$B#
MQ"A;05Q!74%>05]=PP\?0``QP&8/'T0``$$/ME0%`$&(%`9(@\`!A-)U[NN^
M#Q]``$R+#<%\``!)@SD`#X3>````3(G(13'V9F8N#Q^$``````!F#Q]$``!(
M@\`(1(GR08/&`4B#.`!U[T2->@--8_]*C0S]`````(L%JGP``(7`=69(B<],
MB4VPQP65?````0```$B)3;CH3/#__TB)QTB%P`^$0O___TUCQDB+3;A(BW6P
M3HT\Q0````!,B?KHI?+__TB)!2Y\``!(B<=!C48!1(EUQ$B82,<$QP````#I
M1?[__P\?0`!,B<](B<[H5?+__TB)!?Y[``!(B<=(A<`/A.3^__]-8\9.C3S%
M`````.NZ#Q]$```QP.E/_O__N1````!%,?;I3/___^AG\?__#Q^``````%5(
MB>5!5T%6055!5%-(@>P`$```2(,,)`!(@>RX````9$B+!"4H````2(E%R#'`
M28G\28GU2(T]R1L``$B-M2SO___HV/7__[XO````3(GG2(G#Z+CP__](A<!T
M.S'`3(GF2(T]I1L``.@2_?__3(G@2(M5R&1(*Q0E*`````^%B0$``$B-9=A;
M05Q!74%>05]=PP\?1```3(GO3(TM>1L``.B9\/__3(GN2(G'Z,[P__])B<9(
MA<!THT&`/@`/A.H```!F9BX/'X0``````)!(A=MT$TR)]DB)W^B0\/__A<`/
MA*8```!,B??H8.___TF-5`;_28G'23G6<@_K'9#&`@!(@^H!23G6=`6`.B]T
M[TR)]^@W[___28G'3(GGZ"SO__])C40'`4@]_P\```^'*/___TB#[`A,C;W`
M[___38GP,<!!5+H`$```O@(```!,B?](C0T,&P``3(T-NQH``.B)\/__2(VU
M,.___TR)_^CJ[O__6EF%P'42BX5([___)0#P```]`(```'123(GN,?_HZ.__
M_TF)QDB%P`^$N?[__T&`/@`/A2+___](A=MT!8`[+G080;\!````3(TUWQD`
M`.E2____9@\?1```@'L!`'2XZ^`/'X0``````+X!````3(G_Z!/P__^%P'6=
M3(G^2(T]$QH``.B`^___3(G_Z#CO___I9/[__^A.[___9F8N#Q^$```````/
M'P!52(GE05=!5DB-=<1!54R-+>H9``!!5$F)_$R)[U-(@^P89$B+!"4H````
M2(E%R#'`Z,KS__](A<!T"(`X`$B)PW4M2(M%R&1(*P0E*````'5_3(GF2(UE
MV$R)[S'`6T%<05U!7D%?7>GS^O__#Q\`3(GGZ+CM__](B=])B<;HK>W__TV-
M?`8"3(G_Z`#M__](@^P(3(GZ38G@4TB)QTF)QDR-#5,9``!(C0V8&0``O@(`
M```QP.@5[___6%I(BT7(9$@K!"4H````=05,B?;KA.AJ[O__9BX/'X0`````
M`$%53(UL)!!(@^3@0?]U^%5(B>5!5T%63(V]I/[__T%53(G^05132('L:`$`
M`$B)O9C^___%^GX5#'0``$B-/<(8``#%^GX=!70``,7Z?B4%=```Q?I^+05T
M``!D2(L$)2@```!(B47(2(T%-1@``$C'A>#^__\`````2,>%&/___P````#$
MX^DBP`%(C06\&```Q./A(L@!2(T%IQ@``,7Y?X70_O__Q./9(L`!2(T%HQ@`
M`,3C?3C!`<7^?X7X_O__Q./1(L`!,<#%^7^%L/[__TC'A<#^__\`````Q?AW
MZ#OR__](A<!T#(`X`$B)PP^%(@4``.BE[?__B<?H'NS__TB%P`^$500``$R+
M,$V%]@^$200``$R)]^@Q[/__3(UL``%,B>],B>OH@>O__T4/M@9(B860_O__
M28G$183`=%]F9BX/'X0```````\?`$R)ZD4/ML!,B><QP$B-#?T7``"^`@``
M`$F#Q@'H?^W__TPYZTR)ZD4/M@9(#T/32(G03"GH2(/``D@YT$@/0L))*=5)
M@\0"38UL!?Y%A,!UKTR-K?#^__](C3V'%P``ZQ0/'X``````28M]"$F#Q0A(
MA?]T.TR)_C'`Z%'Q__])B<1(A<!TX8`X`'3<2(G'Z/SS__^%P'303(GGZ%#L
M__])B<1(A<!U0`\?A```````3(VMT/[__TV+90!-A>1T*$&`/"0`#X0U`P``
M3(GGZ+WS__^%P`^%%0$``$V+90A)@\4(387D==A,B>?H$.O__TB+G9#^__])
MB<5(B=_H_NK__T6-M`4$!```36/V3(GWZ$OJ__]338G@3(T-K18``$F)Q4B-
M!?06``!,B?*^`@```%!(C0W;%@``3(GO,<#H7.S__TR)[[[``0``Z+_L__]?
M05B#^/]U$NB"Z___1(L(08/Y$0^%*P,``$B-A3#___],B>](B<9(B86(_O__
MZ+SK__^)PX7`#X2"````2(N%F/[__TV)Z$B+/?%U``!(C172%P``O@(```!(
MBP@QP.A;Z?__13'D#Q^$``````!(BT7(9$@K!"4H````#X6Q!```2(UEV$R)
MX%M!7$%=05Y!7UU)C67P05W##Q]$``!,B>=)@\4(Z/3J__])B<1(A<`/A*_^
M___IV_[__P\?`(N%2/___R4`\```/0!````/A6C___]$BZ5,____Z![K__]!
M.<0/A5/___^+A4C___\E_P$``#W``0``#X4]____3(GWZ`?I__],B?Y(C3UW
M%0``28G$,<#H8^___TB%P`^$B@(``$B+C9C^__](B<9(BSGH*/G__TB)A9#^
M__](A<`/A&@"``!(B[V0_O__Z%SI__](B<*#^`-^5$B+C9#^__](F$B--6<5
M``!(B96`_O__2(U\`?SH4^K__X7`=2](BY6`_O__@_H$#X1!`P``2(N-D/[_
M_XU"^TB8@#P!+P^$*P,``&8/'X0``````$R)_DR-/2,5```QP$R)_^B\[O__
M2(7`#X0#`@``#[8`A,`/A/@!```\,`^$\`$``$R)_TB--1<5```QP.CO]?__
M3(T]P!4``.ASZ/__05=,B?)-B>A03(T-<!0``+X"````3(GG2(T-YQ0``#'`
MZ"WJ__]86NM*9@\?A```````Z%OI__^#.!%U2>@QZ/__@\,!2(/L"$V)Z$%7
M3(T-*Q0``$R)\DR)YU-(C0VQ%```O@(```!0,<#HX^G__TB#Q""^P`$``$R)
MY^A"ZO__@_C_=*U,B>_H%>C__TR)YDB-/=`3```QP.A$]?__3(GGZ-SY___I
MQ_W__P\?@`````!%,>3IX/S__P\?A```````2(V=L/[__V8/'X0``````$B+
M.TB%_W0D3(G^,<#HGNW__TB)QTB%P'0%@#@`=4%(BWL(2(/#"$B%_W7<OPT`
M``"[#0```$R--8(3``!!O0T```#H^.;__T&X4P```$B)A9#^__])B<3I@_O_
M_P\?`.AKZ/__2(/#"$B%P'2228G&Z3'[__](BX68_O__38GH2(L]Z7(``$B-
M%8H4``"^`@```$B+"#'`Z%/F___I\_S__V8/'T0``$B)Q^@`^?__2(M%R&1(
M*P0E*`````^%H0$``$B-9=A(B=];05Q!74%>05]=28UE\$%=Z?'G__^02(N%
MF/[__TB+`$B)A9#^___I@OW__V8N#Q^$``````!(B[V0_O__,?8QP.A@Y___
MB<>%P`^$]OW__XF%F/[__^C+[___2(7`#XCB_?__B[V8_O__,=)(C7#V2(F%
MD/[__^@:Z/__B[V8_O__N@8```!(C;6J_O__Z,/E__^+O9C^__](BXV0_O__
M2(/X!@^%]0```(&]JO[__P!#04,/A8S]__]F@;VN_O__2$4/A7W]__\QTDB-
M<<Z)O9C^___HO.?__XN]F/[__[HH````2(N=B/[__TB)WNABY?__2(/X*`^%
MH0```$B-!1D3``"^`@```$V)Z$R)\L:%6/___P!(C0TZ$@``3(T-OA$``$R)
MYU`QP%/HA>?__UE>Z;']__](BX68_O__2(M0"$B%T@^$ROS__TB)UTB)E9C^
M___HN^7__TB#^`,/AK'\__](BY68_O__2(TURQ$``$B-?`+\Z+GF__](BY68
M_O__A<!(#T65D/[__TB)E9#^___I?/S__^B'YO__2(M%R&1(*P0E*````'7L
M2(T]F!$``#'`Z"KM__]F+@\?A```````\P\>^E5(B>5!5T%6055!5$R-):L1
M``!32(U=Q$R)YTB)WDB#[!AD3(L\)2@```!,B7W(3(L]1G```&1-BS=!#[:&
ML````$&(AK$````QP.C,ZO__2(7`=`F`.#$/A%X%``!,C2UI$0``#Q^`````
M`#'`2(G>3(GOZ*/J__](A<!T-DAC5<1(BP4S<```2(T$T$B+4`A(B1!(A=)T
MTP\?`$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$R-+1P1``"0,<!(B=Y,B>_H
M4^K__TB%P'0V2&-5Q$B+!>-O``!(C0302(M0"$B)$$B%TG33#Q\`2(M0$$B#
MP`A(B1!(A=)U\.N^9@\?1```3(TMU!```)`QP$B)WDR)[^@#ZO__2(7`=#9(
M8U7$2(L%DV\``$B-!-!(BU`(2(D02(72=-,/'P!(BU`02(/`"$B)$$B%TG7P
MZ[YF#Q]$``!,C2V-$```D#'`2(G>3(GOZ+/I__](A<!T-DAC5<1(BP5#;P``
M2(T$T$B+4`A(B1!(A=)TTP\?`$B+4!!(@\`(2(D02(72=?#KOF8/'T0``#'`
M2(G>3(GGZ&OI__](A<!T/DAC5<1(BP7[;@``2(T$T$B+4`A(B1!(A=)TTV9F
M+@\?A```````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(TM]`\``)`QP$B)
MWDR)[^@3Z?__2(7`=#9(8U7$2(L%HVX``$B-!-!(BU`(2(D02(72=-,/'P!(
MBU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C2VV#@``D#'`2(G>3(GOZ,/H__](
MA<!T-DAC5<1(BP53;@``2(T$T$B+4`A(B1!(A=)TTP\?`$B+4!!(@\`(2(D0
M2(72=?#KOF8/'T0``#'`2(G>2(T]V0X``.AWZ/__2(7`=#I(8U7$2(L%!VX`
M`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?
M1```3(TU$`\``)`QP$B)WDR)]^@CZ/__2(7`=#9(8U7$2(L%LVT``$B-!-!(
MBU`(2(D02(72=-,/'P!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$```QP$B)WDB-
M/<4.``#HU^?__TB%P'0Z2&-5Q$B+!6=M``!(C0302(M0"$B)$$B%TG3/#Q^`
M`````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``#'`2(G>2(T]>@T``.B'Y___
M2(7`=#I(8U7$2(L%%VT``$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#
MP`A(B1!(A=)U\.NV9@\?1```2(G>2(T],0X``.@YY___2(7`=`U(B<9,B?<Q
MP.B'[O__,<!(B=Y(C3T?#@``Z!;G__](A<!T$4B)QDB-/1T-```QP.A@[O__
M2(G>2(T]#`X``#'`Z._F__](B<9(A<`/A)D!``!,B>\QP.@Y[O__2(TU4PT`
M`$R)YS'`Z"CN__]D38LWN0,```"Z`0```$B-->H-``!,B??H6^#__TF)Q$B%
MP'0I2(M`$&1)BS](C17-#0``2(LPZ&S@__])BT0D$$B+,/9&#D`/A70!``!D
M28L_N0,```"Z`0```$B--:,-``#H$.#__TF)Q$B%P'0Q2(T]/PP``$B)WC'`
MZ$?F__](B<))BT0D$$B+.$B%T@^$&0$``$B)_F1)BS_H!^#__V1)BS^Z`0``
M`$B--5<-``#H(M___V1)BS](C15<#0``2(G&Z-_?__]D28L'2(G>3(GOQH"Q
M`````#'`Z.?E__](B07`:P``2(G#2(7`=$"^P`$``$B)W^@+XO__C5`!@_H!
M=@F#^!$/A<<```!(BT7(9$@K!"4H````#X6O````2(/$&%M!7$%=05Y!7UW#
M2(L]>6L``.AL\O__2(D%96L``$B)PTB%P'6E2(M%R&1(*P0E*````'5V2(T]
M9PT``#'`Z/#@__^`>`$`3(TM.@L```^$B_[__^F,^O__,<!(B=Y(C3UD#```
MZ#GE__](A<`/A%?^__](B<9(C3V#"P``,<#H?^S__^E!_O__2(L5^VH``$B+
M,NB+Z___Z=_^__]D28L_Z"W@___I?O[__^@SX/__2(M5R&1(*Q0E*````'7L
MB<%(BP7#:@``2(G:2(T]^0P``$B+,#'`Z%?@__\/'X``````\P\>^DB+#=5E
M``#I$-[___,/'OI(@^P(2(/$",,`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````!``(`+@!L<V5E:R!F86EL960`<F5A9"!F86EL960`)7,O)7,`1'EN
M84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4
M`"]P<F]C+W-E;&8O97AE`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`3$1?
M3$E"4D%265]0051(`%-94U1%30!005)?5$U01$E2`"]T;7``5$5-4$1)4@!4
M35``55-%4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R
M`%!!4E]#3$5!3@!S:&]R="!R96%D`"5S)7-C86-H92TE<R5S`#$`)7,E<W1E
M;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`%!!4E])3DE424%,25I%1`!015),
M-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?4U!!5TY%1`!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`&`!P97)L
M`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP-C,`+64`+2T``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P
M97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O
M<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````&5V86P@)V5X
M96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*
M;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M
M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD
M1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA
M;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*
M<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK
M7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H
M.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I
M>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK
M7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*
M<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'
M24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^
M/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ
M93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I
M;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E
M<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M
M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-
M4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@
M,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T
M;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@
M+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G
M)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N
M86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B([
M"G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"
M14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H
M<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H
M*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*
M34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S
M<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A
M;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S
M92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,[
M"GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H
M)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T
M<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T
M($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D
M;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B
M=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@
M)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R
M(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@
M(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?
M<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/
M9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T
M+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R
M97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U
M9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT[
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F
M+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY
M("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S
M("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A
M=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT
M*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C
M?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA
M;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D
M;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS
M92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.
M;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G
M;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN
M<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@
M=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E
M=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H
M:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM
M>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G
M22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-
M)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U
M="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E
M)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE
M;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q
M("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T
M(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I
M('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D
M8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G
M?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D
M7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I
M92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F
M.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P
M87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D
M<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]2
M1%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q
M<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E
M*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T[
M"FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO
M9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC
M.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L
M7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X
M="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I
M;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H
M+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*
M?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H
M;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD
M;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%
M("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I
M*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N
M(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D
M9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB
M961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S
M("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T
M85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E
M('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL
M92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH
M97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L
M(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H
M)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&
M:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI
M=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N
M*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z
M("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O
M9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T
M*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD[
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S
M*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@
M97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z
M.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E
M<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R
M('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E
M('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*
M)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@*
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@
M)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P
M871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D[
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.
M5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS
M92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?
M<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@
M)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP
M0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D
M;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#
M2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D
M8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@
M/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?
M9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.
M?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M
M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A
M<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U
M;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN
M86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@[
M"BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H
M("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M
M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA
M;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64[
M"GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]0
M4D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*
M)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[
M4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E
M>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?
M9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?
M9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@
M>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA
M;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y
M<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H
M("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E
M;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!3
M4$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*
M9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0
M($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?
M1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*
M?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F
M:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<
M;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`
M24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q
M=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA
M:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A
M<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,````!&P,[F````!(`
M``"LC___S`````R3___T````;);__V`#```,F?__M`````R:__\,`0``W)K_
M_S@!```,G/__:`$``,R<__^$`0``3)W__Z@!``"LGO__T`$``"R@___\`0``
MC*#__QP"``!LH?__2`(``.RC__]X`@``#*;__Z0"``#LIO__U`(``.RN__\P
M`P``3+7__XP#```4``````````%Z4@`!>!`!&PP'")`!```4````'````%"8
M__\F`````$0'$``````D````-````-B.__]@`P````X01@X82@\+=PB``#\:
M.2HS)"(`````%````%P````0DO__4`,`````````````*````'0```#XF/__
MRP````!!#A"&`D,-!DV/`XX$C06,!H,'`G8*#`<(20LL````H````)R9__\O
M`0```$$.$(8"0PT&4XP#@P0"XPH,!PA!"V$*#`<(10L````8````T````)R:
M__^^`````$$.$(8"0PT&````(````.P```!`F___?`````!!#A"&`D,-!D^#
M`P)C"@P'"$$+)````!`!``"<F___5`$```!!#A"&`D,-!F*-`XP$@P4"S0H,
M!PA%"R@````X`0``U)S__W0!````00X0A@)##090CP..!(T%C`:#!P)`"@P'
M"$0+'````&0!```HGO__6P````!%#A"&`E$-!D6#`V<,!P@H````A`$``&B>
M___8`````$$.$(8"0PT&5XX#C02,!8,&`GP*#`<(00L``"P```"P`0``')__
M_WD"````00X0A@)%#09)CP..!(T%C`:#!P-$`0H,!PA%"P```"@```#@`0``
M;*'__Q("````00X0A@)##09<CP..!(T%C`:#!P)R"@P'"$8++`````P"``!@
MH___U@````!!#A"&`D,-!DJ/`XX$C05)C`9+@P<"1@H,!PA("P``6````#P"
M```0I/__]@<```!"#A"-`D4,#0!,$`8"=@!$$`\"=G@0#@)V<$D/`W9H!DT0
M#`)V8!`#`G98`P(#"@P-`$D,!Q!"#@A&"P/_`@H,#0!)#`<00@X(1@LL````
MF`(``+2K__]9!@```$4.$(8"0PT&2(\#C@2-!8P&2(,'`V\%"@P'"$$+```H
M````R`(```23__^9`@```$4.$(8"0PT&28T#C`2#!0-H`0H,!PA!"P```!``
M``#T`@``N+'__Q``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!@
M*@```````"`J````````H*L```````"A4````````*%1````````CU$`````
M``"R4`````````$`````````W0(````````!`````````.T"````````#```
M````````(`````````T`````````T$4````````9`````````)"K````````
M&P`````````(`````````!H`````````F*L````````<``````````@`````
M````]?[_;P````#0`P````````4`````````.`H````````&``````````@$
M````````"@````````!-`P````````L`````````&``````````5````````
M`````````````P````````#XK0````````(`````````^`0````````4````
M``````<`````````%P````````"P#P````````<`````````D`X````````(
M`````````"`!````````"0`````````8`````````!X`````````"```````
M``#[__]O``````$```@`````_O__;P`````0#@```````/___V\``````0``
M``````#P__]O`````(8-````````)`````````"H%````````",`````````
M$``````````E``````````@`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````R*L`````````````````
M````````````,"````````!`(````````%`@````````8"````````!P(```
M`````(`@````````D"````````"@(````````+`@````````P"````````#0
M(````````.`@````````\"``````````(0```````!`A````````("$`````
M```P(0```````$`A````````4"$```````!@(0```````'`A````````@"$`
M``````"0(0```````*`A````````L"$```````#`(0```````-`A````````
MX"$```````#P(0`````````B````````$"(````````@(@```````#`B````
M````0"(```````!0(@```````&`B````````<"(```````"`(@```````)`B
M````````H"(```````"P(@```````,`B````````T"(```````#@(@``````
M`/`B`````````",````````0(P```````"`C````````,",```````!`(P``
M`````%`C````````8",```````!P(P``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`1T-#.B`H1TY5*2`Q-"XR+C$@
M,C`R-3`Q,3`@*%)E9"!(870@,30N,BXQ+3<I`$%6.C1P,3(X-P!25CIR=6YN
M:6YG(&=C8R`Q-"XR+C$@,C`R-3`Q,3``0E8Z86YN;V)I;B!G8V,@,30N,BXQ
M(#(P,C4P,3$P`$=7.C!X-V0V,#4V,B`N+B]S>7-D97!S+W@X-B]A8FDM;F]T
M92YC`%-0.C,`4T,Z,0!#1CHX("XN+W-Y<V1E<',O>#@V+V%B:2UN;W1E+F,`
M1DPZ,"`N+B]S>7-D97!S+W@X-B]A8FDM;F]T92YC`$=!.C$`4$DZ-`!313HP
M`&E3.C``1U<Z,'@W9#8P-38R(&EN:70N8P!#1CHX(&EN:70N8P!&3#HP(&EN
M:70N8P!!5CHT9S$R.3(`1U<Z,'@V.34P-38R(&QT;P!#1CHX(&QT;P!&3#HM
M,B!L=&\`"````!```````0``1T$D`3-A,0"`*0```````*8I````````"```
M`!```````0``1T$D`3-A,0"F*0```````*8I````````"````!```````0``
M1T$D`3-A,0``(````````!8@````````"````!```````0``1T$D`3-A,0#0
M10```````-A%````````"````!```````0``1T$D`3-A,0"P*0```````&DJ
M````````"````!```````0``1T$D`3-A,0#`10```````-!%````````"```
M`!```````0``1T$D`3-A,0#010```````-!%````````"````!```````0``
M1T$D`3-A,0#010```````-!%````````"````!```````0``1T$D`3-A,0`6
M(````````!L@````````"````!```````0``1T$D`3-A,0#810```````-U%
M`````````"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N
M;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M82YD>6X`+G)E;&$N<&QT`"YR96QR+F1Y;@`N:6YI=``N<&QT+G-E8P`N=&5X
M=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET
M7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD871A+G)E;"YR;P`N9'EN86UI8P`N9V]T
M`"YD871A`"YB<W,`+F-O;6UE;G0`+F%N;F]B:6XN;F]T97,`+F=N=2YB=6EL
M9"YA='1R:6)U=&5S````````````````````````````````````````````
M``````````````````````````````````````````````L````!`````@``
M```````8`P```````!@#````````'`````````````````````$`````````
M```````````3````!P````(`````````.`,````````X`P```````%``````
M```````````````(````````````````````)@````<````"`````````(@#
M````````B`,````````D````````````````````!```````````````````
M`#D````'`````@````````"L`P```````*P#````````(```````````````
M``````0```````````````````!'````]O__;P(`````````T`,```````#0
M`P```````#0`````````!@`````````(````````````````````40````L`
M```"``````````@$````````"`0````````P!@````````<````!````"```
M```````8`````````%D````#`````@`````````X"@```````#@*````````
M30,```````````````````$```````````````````!A````____;P(`````
M````A@T```````"&#0```````(0`````````!@`````````"``````````(`
M````````;@```/[__V\"`````````!`.````````$`X```````"`````````
M``<````!````"````````````````````'T````$`````@````````"0#@``
M`````)`.````````(`$````````&``````````@`````````&`````````"'
M````!````$(`````````L`\```````"P#P```````/@$````````!@```!D`
M```(`````````!@`````````D0```!,````"`````````*@4````````J!0`
M```````0````````````````````"``````````(`````````)L````!````
M!@``````````(``````````@````````&P````````````````````0`````
M``````````````",`````0````8`````````("`````````@(````````&`#
M```````````````````0`````````!``````````H0````$````&````````
M`(`C````````@",```````!0`P``````````````````$``````````0````
M`````*H````!````!@````````#@)@```````.`F````````\!X`````````
M`````````"````````````````````"P`````0````8`````````T$4`````
M``#010````````T````````````````````$````````````````````M@``
M``$````"``````````!0`````````%````````!R0```````````````````
M"````````````````````+X````!`````@````````!TD````````'20````
M````G`````````````````````0```````````````````#,`````0````(`
M````````$)$````````0D0````````@#```````````````````(````````
M````````````U@````X````#`````````)"K````````D)L````````(````
M````````````````"``````````(`````````.(````/`````P````````"8
MJP```````)B;````````"`````````````````````@`````````"```````
M``#N`````0````,`````````H*L```````"@FP```````"@`````````````
M```````(````````````````````^P````8````#`````````,BK````````
MR)L````````P`@````````<`````````"``````````0``````````0!```!
M`````P````````#XK0```````/B=````````"`(```````````````````@`
M````````"``````````)`0```0````,``````````+``````````H```````
M`!$````````````````````(````````````````````#P$```@````#````
M`````""P````````$:````````!0````````````````````(```````````
M`````````!0!```!````,````````````````````!&@````````+@``````
M``````````````$``````````0`````````=`0```0```#``````````````
M```````_H````````"4!```````````````````!``````````$`````````
M+`$```<``````````````'#0````````9*$```````!H`0``````````````
M````!`````````````````````$````#`````````````````````````,RB
F````````0@$```````````````````$`````````````````````
